@@ -12,5 +12,5 @@ source $AMZ_CONFIG/python-argcomplete
 
 ## Utilities
 alias amz_ssh_pilatus="ssh amz@10.33.0.2 -X"
-alias amz_export_ros_pilatus="export ROS_MASTER_URI=http://10.33.0.2:11311"
+alias amz_car_master="export ROS_MASTER_URI=http://10.33.0.2:11311 ROS_IP=$(hostname --all-ip-addresses | grep 10.33.0)"
 alias amz_monitoring="export ROS_MASTER_URI=http://10.33.0.2:11311 && rosrun monitoring_display node_start.py --columns 4"
